@@ -3,10 +3,8 @@ import gzip
 import io
 import json
 import logging
-import pickle
-import sys
+
 import time
-import zlib
 
 
 import socketio
@@ -15,22 +13,25 @@ import ujson as ujson
 from multiprocessing.dummy import Pool
 
 
+
 class GSCNodeFunctionReceiverSocket:
     @classmethod
-    def create(cls, sio, gsdbs, oncnodefunction):
+    def create(cls, sio, gsdbs, oncnodefunction, poolsize):
         self = GSCNodeFunctionReceiverSocket()
         self.sio = sio
         self.gsdbs = gsdbs
         self._pool = Pool(self.gsdbs.credentials["poolsize"])
         self.oncnodefunction = oncnodefunction
         self._logger = logging.getLogger(__name__)
+        self.poolsize = poolsize
 
         @self.sio.event
         def connect():
             self._logger.info('oncnodefunction connected')
 
         def on_success(r):
-            self._logger.info('cnodefunction succeed')
+            pass
+            # self._logger.info('cnodefunction succeed')
 
         def on_errorPost(error):
             self._logger.exception('cnodefunction failed :' + error)
@@ -50,7 +51,7 @@ class GSCNodeFunctionReceiverSocket:
             connectURL = self.gsdbs.credentials["signalserver"]
 
         self.sio.connect(
-            f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}{self.gsdbs.credentials["cnode"]}&global=true')
+            f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}{self.gsdbs.credentials["cnode"]}&global=true&poolsize={self.poolsize}')
         self.sio.wait()
 
     def sendcnodefunctionResult(self, id, msg):
@@ -58,13 +59,14 @@ class GSCNodeFunctionReceiverSocket:
 
 
 class GSCNodeFunctionReceiver:
-    def __init__(self, gsdbs, oncnodefunction):
+    def __init__(self, gsdbs, oncnodefunction, poolsize):
         self.sio = socketio.Client()
         self.gsdbs = gsdbs
         self.oncnodefunction = oncnodefunction
+        self.poolsize = poolsize
 
     def startSocket(self):
-        GSCNodeFunctionReceiverSocket.create(self.sio, self.gsdbs, self.oncnodefunction)
+        GSCNodeFunctionReceiverSocket.create(self.sio, self.gsdbs, self.oncnodefunction, self.poolsize)
 
     def sendcnodefunctionanswer(self, id, msg):
         self.sio.emit("answer", {"id": id, "message": ujson.dumps(msg)})
@@ -85,7 +87,10 @@ class GSCNodeFunctionCallerSocket:
 
         @self.sio.event
         def answer(id, message):
-            self.oncnodefunctionanswer(self.gsdbs, ujson.loads(message))
+            if (type(message) is dict):
+                self.oncnodefunctionanswer(self.gsdbs, message)
+            else:
+                self.oncnodefunctionanswer(self.gsdbs, ujson.loads(message))
 
         connectURL = ""
 
